﻿using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using ProxmoxConnector.Integration.Abstractions;
using ProxmoxConnector.Server.Application.Queries;
using System;
using System.Threading.Tasks;

namespace ProxmoxConnector.Server.Controllers
{
    [Authorize]
    [ApiController]
    [Route("connector")]
    public class ConnectorController : ControllerBase
    {
        private readonly IMediator _mediator;
        private readonly IPveConnector _pveConnector;

        public ConnectorController(IMediator mediator, IPveConnector pveConnector)
        {
            _mediator=mediator;
            _pveConnector=pveConnector;
        }

        [AllowAnonymous]
        [HttpGet("test")]
        public async Task<IActionResult> TestQ([FromRoute] TestQ.Query query)
        {
            var result = await _mediator.Send(query);
            return Ok(result);
        }

        [AllowAnonymous]
        [HttpGet("start")]
        public async Task<IActionResult> Start()
        {
            await _pveConnector.Start();
            return Ok(DateTime.Now);
        }


        [AllowAnonymous]
        [HttpGet("stop")]
        public async Task<IActionResult> Stop()
        {
            await _pveConnector.Stop();
            return Ok(DateTime.Now);
        }
    }
}
